@@ -1,4 +1,4 @@
-"""多维多时间序列神经网络滚动训练数据工具箱.
+"""多维多时间序列神经网络滚动训练的数据工具.
 
 version:0.3
 
@@ -18,7 +18,8 @@ class TimeSeriesData:
     """单个时间序列信息.
 
     Notes:
-        储存个股的数据信息及预测目标，全部使用numpy，日期格式为整数: ``YYYYMMDD``.
+        用于储存个股的数据信息及预测label，全部使用numpy，日期格式为整数: ``YYYYMMDD``。
+        数据分三个部分：时间，数据，标签，第一个维度都是时间，数据的第二个维度为特征。
 
     """
 
@@ -29,7 +30,7 @@ class TimeSeriesData:
         """储存个股的数据信息及预测目标，全部使用numpy，日期格式为整数: ``YYYYMMDD``.
 
         Args:
-            dates: 日期列, 1D ``numpy.ndarray``
+            dates: 日期列, 1D ``numpy.ndarray``, 整数
             data: 训练输入的X，2D ``numpy.ndarray``, (日期长度 x 特征数量)
             labels: 训练标签Y, 1D ``numpy.ndarray``, 长度与dates相同
 
@@ -51,7 +52,7 @@ class TimeSeriesData:
 
 
 class TrainValData:
-    """该类用于生成不同训练阶段的tensorflow dataset."""
+    """根据训练天数、验证天数、样本历史长度、训练起点生成不同训练阶段的数据."""
 
     def __init__(self,
                  time_series_list: _List[TimeSeriesData],
@@ -64,34 +65,41 @@ class TrainValData:
         """用于获取不同阶段的训练集和验证集.
 
         Notes:
-            储存全部的时间序列信息，通过get(start_date)方法获取从start_date
-            开始的训练机和验证集。
+            ``time_series_list``储存全部的时间序列信息，
+            其中每支股票序列为一个单独``TimeSeriesData``，
+            完整数据为``List[TimeSeriesData]``类型。
 
-            train_val_gap参数为验证集第一天与训练集最后一天中间间隔的天数，
-            如果是相临，则train_val_gap = 0。
+            此外需要提供训练集总交易天数(``train_length``)、
+            验证集总交易天数(``validate_length``)、
+            单个样本用到的历史长度(``history_length``)、
+            采样步进大小(``sample_step``)。
 
-            设置该参数的目的如下：
+            使用方法为：通过get(start_date)方法获取从start_date
+            开始的训练机和验证集。通过逐渐增大start_date训练多个模型回测。
+
+            ``train_val_gap``参数为验证集第一天与训练集最后一天中间间隔的天数，
+            如果是相临，则train_val_gap = 0。设置该参数的目的如下：
 
             如果希望预测未来十天的累计收益，则预测时用到的输入数据为最近的历史数据来预测
             未来十天的累计收益，即用t(-history)到t(0)的数据来预测t(1)到t(11)的累计收益
             而训练时因为要用到十天累计收益做标签，最近的一个十天累计收益是从t(-10)到t(0)，
-            用到的历史数据则必须是t(-history-11)到t(-11)的数据，为了确保validation的
-            有效性，则最好将validation的第一个数据位置与train的最后一个数据位置在时间上
-            相差11天，即间隔10天，因此使用train_val_gap=10。
+            用到的历史数据则必须是t(-history-11)到t(-11)的数据。
+            而validation时，如果第一个预测点是t(1)(明天收盘价)至t(11)的累计收益，
+            则与最后一个训练的数据即：t(-10)至t(0)之间间隔了10天，
+            使用``train_val_gap=10``。
 
-            时间为t(0)的每个样本数据的历史数据时间范围为t(-30)至t(0)，
-            即用到了当天的收盘数据。标签数据为 p(11) / p(1) - 1，
-            即往后11天的收盘价除以明天的收盘价减去1。不用 p(10) / p(0) - 1 的原因是，
-            当天收盘时未做预测，不能以当天收盘价购入。
+            可选项为fill_na，缺失数据填充值，默认为np.Na
+            训练时跳过所有有缺失数据的样本。
 
         Args:
             time_series_list: TimeSeriesData 列表
             train_length: 训练集天数
             validate_length: 验证集天数
-            history_length: 每个sample的历史天数
+            history_length: 每个样本的历史天数
             train_val_gap: 训练集与验证集的间隔
             sample_step: 采样sample时步进的天数
             fill_na: 默认填充为np.NaN，训练时会跳过有确实数据的样本
+
         """
         # 检查参数类型
         if type(time_series_list) is not list:
@@ -173,28 +181,33 @@ class TrainValData:
             根据设定的训练集天数以及验证集天数，从start_date开始获取正确的
             训练集以及验证集，以及他们各自的日期范围信息(该信息以字典形式返回)。
 
-            training set 的开始和结束是指其data, label所有的时间范围(inclusive)。
-            validation set 的开始和结束则只是指其label的时间范围，
-            因为validation set允许用到training set内的X历史数据。
-            具体时间信息参考返回的第三个元素dates_info。
+            需要注意:
+            训练集的的开始和结束是指其data, label时间范围并集，而
+            验证集的开始和结束则只是指其label的时间范围。
+            验证集的输入数据可以与训练集重叠，只要其标签数据的包含的时间范围
+            与训练集数据包含的时间范围没有交集即可。
 
-            如果日期范围超出最大日期会报ValueError。
+            具体时间信息参考函数返回的最后一个元素，是一个包含时间信息的``dict``。
 
         Args:
             start_date: 该轮训练开始日期，整数``YYYYMMDD``
             order: 有三种顺序 ``shuffle``, ``by_date``, ``by_series``。
                 分别为随机打乱股票和时间，按时间顺序优先，按股票顺序优先，默认by_date。
             mode: `generator` 或 `in_memory`. generator 速度极慢，
-                in_memory速度较快，默认in_memory。feature、series数量大内存不足时
-                可以使用generator。'in_memory'模式股票数量较大以及step较小时，
+                in_memory速度较快，默认in_memory。feature、series数量大显存不足时
+                可以使用generator。
+                'in_memory'模式股票数量较大、history_length较大、或者step较小时，
                 可能会要求较大显卡内存。
             validate_only: 如果设置为True，则只返回validate set
-                和训练集、验证集时间信息
+                和训练集、验证集时间信息。可以用于训练后的分析。
 
         Returns:
-            如果``validate_only=False``，返回训练集、验证集，以及日期信息：
-            (train, val, dates_info(dict))。如果为``True``，则返回
-            验证集以及日期信息。
+            如果``validate_only=False``，返回训练集、验证集、日期信息：
+            (train, val, dates_info(dict))。
+            如果为``True``，则返回验证集、日期信息。
+
+        Raises:
+            ValueError: 日期范围超出最大日期会报ValueError。
 
         """
         if mode == "generator":
@@ -242,17 +255,6 @@ class TrainValData:
         # 获取用于构建训练集、验证集的相关信息
         train_args, val_args, dates_info = self.__get_period_info__(start_date,
                                                                     order)
-        sig = (
-            _tf.TensorSpec(
-                shape=(self.__history_length,
-                       self.__feature_counts),
-                dtype=_tf.float32
-            ),
-            _tf.TensorSpec(
-                shape=(),
-                dtype=_tf.float32
-            )
-        )
         shapes = (_tf.TensorShape((self.__history_length,
                                    self.__feature_counts)),
                   _tf.TensorShape(()))
